#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#
#  Documentation: for Shiny 1.6
# https://shiny.rstudio.com/reference/shiny/1.6.0/


## Example shiny app:
## obereed.net:3838/mnist

## Instructions:
## Build a shiny app from this simplified default template.

## 1. - Instead of old faithful geyser, generate a 1000 random values and plot this with a histogram.
## 2. change the title
## 3. Also plot the values you generated against the vals variable using a qqplot.
## 4. Add some other html using tags$ or one of the tags shortcuts

library(shiny)

##read the following in only once:
vals <- runif(5000)


# Define UI for application that draws a histogram
ui <- fluidPage(

    # Application title
    titlePanel("Not Old Faithful Geyser Data"),
      h1("h1 title"),
      img(src="saling.png"),
      tags$b(h1("title1")),
      
     sliderInput("bins",
                        "Number of bins:",
                        min = 1,
                        max = 50,
                        value = 30),

    
    # Show a plot of the generated distribution
    plotOutput("distPlot"),
    plotOutput("qqPlot")
    
)

# Define server logic required to draw a histogram
server <- function(input, output) {

    output$distPlot <- renderPlot({
        # generate bins based on input$bins from ui.R
        x    <- runif(1000)
        bins <- seq(min(x), max(x), length.out = input$bins + 1)
        par(mfrow=c(1,2))
        # draw the histogram with the specified number of bins
        hist(x, breaks = bins, col = 'darkgray', border = 'white')
        qqplot(x,vals)
        
    })
    
    
    output$qqPlot <- renderPlot({
      # generate bins based on input$bins from ui.R
      x    <- runif(1000)
     
      par(mfrow=c(1,1))
      # draw the histogram with the specified number of bins
      qqplot(x,vals)
      
    })
    
}

# Run the application 
shinyApp(ui = ui, server = server)
