#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#
## Tabs
##  
## This is getting pretty packed.  We can maybe move some of the 
## graphics and tables to a second or third tab, using tabSetPanel() and tabPanel.
## These get used inside fluidpage, and can use the sidebarlayout within a tabPanel, 
## 
##
##  So you can use
## ui <- fluidPage(tabsetPanel(
#    tabPanel("name", ui, elements),
#    tabPanel("name2", ui, elements),
#    tabPanel("name3", ui,elements)
#))

## and add interface elements within each tabPanel(). That is, instead of elements, write a code 
## block within {} brackets.  Note that this can be done just by reorganizing the ui--nothing needs to change 
## in the server.
##
##
## Instructions.  Add a tabset to the ui. 
## * Replace the sidebar/main panel with separate tabs so the control elements are on one tab
## * Add several other tabs for each graphical element you think should be separated.
## * Be sure to name each tab Put at least one of the graphics on a second panel. 
 
## Be sure these are installed!
library(ggplot2)
library(plotly)
library(shiny)
library(tidyverse)

# Define UI for application that draws a histogram
ui <- fluidPage(
  
  
  # Application title
  titlePanel("Random distribution generation"),
  
  # Sidebar with a slider input for number of bins 
  sidebarLayout(
    sidebarPanel(
      sliderInput("bins",                        "Number of bins:",
                  min = 1,
                  max = 50,
                  value = 30),
      selectInput("type",label="Select form of distribution",
                  choices=c("normal","uniform")),
      numericInput("number","Number of samples",500,min=100,max=10000,step=100,width='100%'),
      
      
      tags$a("Link to wikipedia",href="http://en.wikipedia.org"),
      tags$p(),
      tags$hr(),
      tags$a( tags$img(src="https://upload.wikimedia.org/wikipedia/en/c/c9/Michigan_Technological_University_logo.svg"),
              href="http://mtu.edu")
    ),
    
    # Show a plot of the generated distribution
    mainPanel(
      h1("Histograms"),
      plotOutput("distPlot"),
      plotOutput("distPlot2",width=400, height=400),
      plotlyOutput("niceplot2",width=500, height=500),
      actionButton("save","Save table to log file"),
      tableOutput("table"),
      h3("Overview in text:"),
      textOutput("textdesc")
    )
  )
)

server <- function(input, output,session) {
  data <- reactive(
    {
      
      if( input$type=="normal")
      {
        x    <-  rnorm(input$number)  
        updateNumericInput(session,"bins",value=25)
      }else if(input$type=="uniform")
      {
        x    <-  runif(input$number) 
        updateNumericInput(session,"bins",value=10)
      }
      
      x
    }
    
    
  )
  
  summaryTable <- reactive(
    {
      a <- data()
      atab <-summary(as.data.frame(a))
      atab
    }
  )
  
  
  observeEvent(input$save,
               {
                 print("SAVING")
                 #             x <- data()
                 #             tmp <- as.data.frame(summary(as.data.frame(x)))
                 tmp <- summaryTable()
                 write.table(t(tmp),file="logfile.csv",append=T,sep=",",col.names=F)
                 print("writing log file")
                 
                 
               })
  
  
  
  output$distPlot <- renderPlot({
    x <- data()
    
    # draw the histogram with the specified number of bins
    a <- as.data.frame(x) |> ggplot(aes(x=x)) +geom_histogram(bins=input$bins,fill="orange2",color="black") + theme_bw()
    print(a)
  })
  
  
  
  output$distPlot2 <- renderPlot({
    x <- data()
    # draw the histogram with the specified number of bins
    b <- as.data.frame(x) |> ggplot(aes(sample=x)) + geom_qq() + theme_bw()
    print(b)
  })
  
  
  
  output$niceplot2 <- renderPlotly({
    
    x <- data()
    y <-  x + rnorm(length(x)) * 2
    tmp <- data.frame(x,y)
    plot_ly(tmp,x=~x,y=~y,type="scatter",mode="markers")
    
  })
  
  
  output$table<- renderTable({
    xx <- summaryTable()
    as.data.frame(xx)
  })
  
  
  output$textdesc <- renderText(
    paste("using ",input$type," distribution with a mean of ", round(mean(data()),3),
          " and standard devation of",round(sd(data()),3),"\n")
  )
  
}

# Run the application 
shinyApp(ui = ui, server = server)

