#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

## Instructions:
## * Change the radioButton to a selectInput  interface.
## * I have added an interface that will let you specify how many samples you want.  Add code in the server to 
## use this selection.

library(shiny)
library(ggplot2)
library(gridExtra)


# Define UI for application that draws a histogram
ui <- fluidPage(
  
  # Application title
  titlePanel("Random distribution generation"),
  
  # Sidebar with a slider input for number of bins 
  sidebarLayout(
    sidebarPanel(
      sliderInput("bins",
                  "Number of bins:",
                  min = 1,
                  max = 50,
                  value = 30),
      radioButtons("type","Select the distribution",choices=c("uniform","normal")),
      numericInput("number","Number of samples",500,min=100,max=10000,step=100,width='100%'),
      tags$a("Link to wikipedia",href="http://en.wikipedia.org"),
      tags$p(),
      tags$hr(),
      tags$img(src="https://upload.wikimedia.org/wikipedia/en/c/c9/Michigan_Technological_University_logo.svg")
    ),
    
    # Show a plot of the generated distribution
    mainPanel(
      h1("Histogram and normal q-q plot"),
      plotOutput("distPlot")
    )
  )
)


# Define server logic required to draw a histogram
server <- function(input, output) {

  
output$distPlot <- renderPlot({
    n <- 1000
    
    if(input$type=="uniform")
    {
      x    <- runif(n)
    } else if(input$type=="normal")
    {
      x    <-  rnorm(n)
    } else{
      x <- 1:n
    }
    
    # draw the histogram with the specified number of bins
    a <- as.data.frame(x) |> ggplot(aes(x=x)) +geom_histogram(bins=input$bins,fill="orange2",color="black") + theme_bw()
    b <- as.data.frame(x) |> ggplot(aes(sample=x)) + geom_qq() + theme_bw()
    grid.arrange(a,b,ncol=2)
    
  })
}
  
# Run the application 
shinyApp(ui = ui, server = server)


